pub async fn delete_older_than(
conn: &mut PgConnection,
cutoff: DateTime<Utc>,
limit: i64,
) -> ModelResult<u64>Expand description
Deletes up to limit outcomes checked before cutoff and returns how many went.
pub async fn delete_older_than(
conn: &mut PgConnection,
cutoff: DateTime<Utc>,
limit: i64,
) -> ModelResult<u64>Deletes up to limit outcomes checked before cutoff and returns how many went.