pub async fn get_findings_since(
conn: &mut PgConnection,
since: DateTime<Utc>,
) -> ModelResult<Vec<EnrolmentCheckFindings>>Expand description
What the checks answered since since found, per group, step and source.
pub async fn get_findings_since(
conn: &mut PgConnection,
since: DateTime<Utc>,
) -> ModelResult<Vec<EnrolmentCheckFindings>>What the checks answered since since found, per group, step and source.