pub struct EnrolmentCheckFindings {
pub enrolment_check_group: EnrolmentCheckGroup,
pub enrolment_check_step: Option<i32>,
pub source: EnrolmentCheckSource,
pub check_count: i64,
pub found_count: i64,
pub p50_detection_secs: Option<f64>,
pub p95_detection_secs: Option<f64>,
}Expand description
What the checks of one group, step and source found.
Fields
enrolment_check_group: EnrolmentCheckGroupenrolment_check_step: Option<i32>None for checks of rows whose schedule had run out.
source: EnrolmentCheckSourcecheck_count: i64found_count: i64p50_detection_secs: Option<f64>Time from the enrolment, as Sisu records it, to the check that found it; over the finds that carry an enrolment time.
p95_detection_secs: Option<f64>Trait Implementations
Sourceimpl Clone for EnrolmentCheckFindings
impl Clone for EnrolmentCheckFindings
Sourcefn clone(&self) -> EnrolmentCheckFindings
fn clone(&self) -> EnrolmentCheckFindings
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for EnrolmentCheckFindings
impl ComposeSchema for EnrolmentCheckFindings
Sourceimpl Debug for EnrolmentCheckFindings
impl Debug for EnrolmentCheckFindings
Sourceimpl<'de> Deserialize<'de> for EnrolmentCheckFindings
impl<'de> Deserialize<'de> for EnrolmentCheckFindings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for EnrolmentCheckFindings
impl PartialEq for EnrolmentCheckFindings
Sourceimpl Serialize for EnrolmentCheckFindings
impl Serialize for EnrolmentCheckFindings
Sourceimpl ToSchema for EnrolmentCheckFindings
impl ToSchema for EnrolmentCheckFindings
impl StructuralPartialEq for EnrolmentCheckFindings